[![PyPI version](https://badge.fury.io/py/heliumcli.svg)](https://badge.fury.io/py/heliumcli)
[![Build Status](https://travis-ci.org/HeliumEdu/heliumcli.svg?branch=master)](https://travis-ci.org/HeliumEdu/heliumcli)
[![codecov](https://codecov.io/gh/HeliumEdu/heliumcli/branch/master/graph/badge.svg)](https://codecov.io/gh/HeliumEdu/heliumcli)
[![image](https://img.shields.io/pypi/pyversions/heliumcli.svg)](https://pypi.org/project/heliumcli/)
[![PyPI license](https://img.shields.io/pypi/l/heliumcli.svg)](https://pypi.org/project/heliumcli/)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://www.paypal.me/alexdlaird)

# Helium CLI

## Prerequisites

- Python (>=2.7, >= 3.5)
- Pip (>= 9.0)

## Getting Started

The Helium CLI can easily be used with a compatible project by installing it with `pip install heliumcli`. The utility
is then available from the command line with `helium-cli`.

More details pertaining to project compatibility, installation, and configuration can be found in the [Helium CLI Wiki](https://github.com/HeliumEdu/heliumcli/wiki).
